@@ -532,7 +532,10 @@ class FireXTask(Task):
 
     def _process_arguments_and_run(self, *args, **kwargs):
         # Organise the input args by creating a BagOfGoodies
-        self.context.bog = BagOfGoodies(self.sig, args, kwargs)
+        self.context.bog = BagOfGoodies(self.sig,
+                                        args,
+                                        kwargs,
+                                        has_returns_from_previous_task=kwargs.get('chain_depth', 0) > 0)
 
         # run any "pre" converters attached to this task
         converted = ConverterRegister.task_convert(task_name=self.name, pre_task=True, **self.bag)
@@ -606,7 +609,11 @@ class FireXTask(Task):
         params = sig.parameters
         for param in params.values():
             if param.name not in bound_args:
-                default_bound_args[param.name] = param.default
+                if param.default == param.empty and param.kind == param.VAR_POSITIONAL:
+                    # The param.default is set to param.empty in such cases, and need to be a tuple instead
+                    default_bound_args[param.name] = tuple()
+                else:
+                    default_bound_args[param.name] = param.default
         return default_bound_args
 
     @property
@@ -626,7 +633,10 @@ class FireXTask(Task):
         return self._get_default_bound_args(self.sig, self.bound_args)
 
     def map_input_args_kwargs(self, *args, **kwargs) -> ((), {}):
-        b = BagOfGoodies(self.sig, *args, **kwargs)
+        b = BagOfGoodies(self.sig,
+                         *args,
+                         **kwargs,
+                         has_returns_from_previous_task=kwargs.get('chain_depth', 0) > 0)
         return b.args, b.kwargs
 
     def map_args(self, *args, **kwargs) -> dict:
